@@ -1,8 +1,9 @@
-__version__ = "0.0.16"
+__version__ = "0.0.18"
 
-from src.sigla.lib import from_xml
+from sigla.lib import from_xml
 
 
 def process_node(root):
     node = from_xml(root)
     node.process()
+
